aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/android
diff options
context:
space:
mode:
Diffstat (limited to 'include/android')
-rw-r--r--include/android/SkAnimatedImage.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/include/android/SkAnimatedImage.h b/include/android/SkAnimatedImage.h
index d2f4e3d66c..dc1ce0ac64 100644
--- a/include/android/SkAnimatedImage.h
+++ b/include/android/SkAnimatedImage.h
@@ -75,12 +75,16 @@ public:
bool isFinished() const { return fFinished; }
/**
+ * Returned by update if the animation is not running.
+ */
+ static constexpr double kNotRunning = -2.0;
+
+ /**
* Update the current time. If the image is animating, this may decode
* a new frame.
*
* @return the time to show the next frame.
* Returns numeric_limits<double>::max() if there is no max frame to
* show, and -1.0 if the animation is not running.
*/
double update(double msecs);
@@ -75,12 +75,16 @@ public:
* a new frame.
*
- * @return the time to show the next frame.
- * Returns numeric_limits<double>::max() if there is no max frame to
- * show, and -1.0 if the animation is not running.
+ * @return the time to show the next frame, or kNotRunning if the animation
+ * is not running.
*/
double update(double msecs);